#!/bin/csh 
#PBS -o /u/mid/omannik/restart_tube/small/crush_tube.log
#PBS -e /u/mid/omannik/restart_tube/small/crush_tube.err
#PBS -q dyna
#PBS -l nodes=1:ppn=4:dyna
#PBS -m abe
#PBS -f
#PBS -l walltime=99:99:99:99
#
# License file variables
#
if(! $?OA_INSTALL) then
  setenv OA_INSTALL /data4/dyna15/rhe6_64_executables
endif
setenv LSTC_LICENSE_SERVER vdgsrv01
setenv LSTC_NOCLIENT ON
setenv LSTC_LICENSE network
setenv LSTC_MEMORY auto
setenv LM_LICENSE_FILE @vdgsrv01:@atgsrv01
#
# Job variables
#
setenv LSDYNA_VERSION /prg/LINUX/DYNA_EXECUTABLES/R10.1.0/ls-dyna_mpp_d_r10_1_123355_x64_redhat54_ifort160_sse2_intelmpi-413.exe
setenv LSDYNA_MPP TRUE
setenv LSDYNA_MPI_TYPE IMPI
setenv LSDYNA_HYBRID FALSE
setenv LSDYNA_DOUBLE TRUE
setenv LSDYNA_ONLINE FALSE
setenv LSDYNA_BACKGROUND FALSE
setenv LSDYNA_BATCH FALSE
setenv LSDYNA_QUEUE TRUE
setenv LSDYNA_QUEUE_NAME dyna
setenv LSDYNA_QUEUE_COMMAND_1 #PBS -l nodes=1:ppn=4:dyna
setenv LSDYNA_JOB_NAME crush_tube.key
setenv LSDYNA_JOB_DIR /u/mid/omannik/restart_tube/small
setenv LSDYNA_JOB_FILE crush_tube.temp
setenv LSDYNA_JOB_CPUS 4
setenv LSDYNA_HYBRID_MPP_THREADS 1
setenv LSDYNA_HYBRID_SMP_THREADS 1
setenv LSDYNA_USER_ID omannik
setenv LSDYNA_CL_ARGS
#
# Change to Job Directory
#
pushd /u/mid/omannik/restart_tube/small
rm -f messag
rm -f mes[0-9][0-9][0-9][0-9]
rm -f messag[0-9][0-9][0-9][0-9]
rm -f dyna.d
rm -f disk8*
rm -f status.out
#
#
# The following Environment Variables are available for this script
#
# $LSDYNA_VERSION       :       full pathname of selected LS-DYNA executable
# $LSDYNA_MPP           :       TRUE if MPP version selected
# $LSDYNA_MPI_TYPE      :       MPI version
# $LSDYNA_DOUBLE        :       TRUE if double precision version selected
# $LSDYNA_ONLINE        :       TRUE if the job has been submitted ONLINE
# $LSDYNA_BACKGROUND    :       TRUE if the job has been submitted to BACKGROUND
# $LSDYNA_BATCH         :       TRUE if the job has been submitted using BATCH
# $LSDYNA_QUEUE         :       TRUE if the job has been submitted to a QUEUE
# $LSDYNA_JOB_DIR       :       full path of LS-DYNA job_directory
# $LSDYNA_JOB_FILE      :       filename containing LS-DYNA job options
# $LSDYNA_JOB_CPUS      :       number of CPU's selected
# $LSDYNA_USER_ID       :       username
# $LSDYNA_LOCAL_HOST    :       TRUE if submitting MPP jobs to the local machine
# $LSDYNA_NODE_FILE     :       TRUE if submitting MPP jobs using a Node File
# $NODE_FILE            :       filename containing node list for MPP jobs
# $LSDYNA_LOCAL_HOST    :       TRUE if submitting MPP jobs using a Node List
# $NODE_LIST            :       string containing node list for MPP jobs
# $LSDYNA_CL_ARGS       :       string containing command line arguments
# $LSDYNA_HYBRID        :       TRUE if HYBRID version selected
# $LSDYNA_MPP_THREADS   :       Number of MPP threads selected for the HYBRID version
# $LSDYNA_SMP_THREADS   :       Number of SMP threads selected for the HYBRID version
#
#
# 
# ============================================================================================
# MACHINE SPECIFIC VARIABLES   -  uncomment as required
#
#
# IBM AIX
# -------
# setenv YIELDLOOPTIME 10000000
# setenv SPINLOOPTIME  1000000
# setenv AIXTHREAD_SCOPE S
# setenv MP_PROCS $LSDYNA_JOB_CPUS
# setenv MP_LABELIO no
# setenv MP_EUILIB us
# setenv MP_EUIDEVICE css0
#
#
# SGI IRIX
# --------
# setenv MPC_GANG off
# setenv OMP_DYNAMIC FALSE
# setenv OMP_SET_NUMTHREADS $LSDYNA_JOB_CPUS
# setenv _DSM_PPM 2
# setenv _DSM_PLACEMENT ROUND_ROBIN
# setenv TRAP_FPE  "OVERFL=ABORT; DIVZERO=ABORT; INVALID=ABORT; INT_OVERFL=ABORT"
#
# ============================================================================================
#
#
# ============================================================================================
# MACHINE SPECIFIC MPP submission commands
#
# # HP ALPHA
# --------
# dmpirun -np $LSDYNA_JOB_CPUS $LSDYNA_VERSION
#
#
# HP PA8000 and Itanium2 (HP-MPI)
# ----------------------
# mpirun -np $LSDYNA_JOB_CPUS $LSDYNA_VERSION < $LSDYNA_JOB_FILE        (single node)
#
# mpirun -f appfile     (multiple nodes)
#        where appfile contains
#
#       -h hostname_1st -np #1 -e MPI_WORKDIR=<workdir> $LSDYNA_VERSION < $LSDYNA_JOB_FILE
#       -h hostname_2nd -np #2 -e MPI_WORKDIR=<workdir> $LSDYNA_VERSION
#       -h hostname_3rd -np #3 -e MPI_WORKDIR=<workdir> $LSDYNA_VERSION
#       -h hostname_4th -np #4 -e MPI_WORKDIR=<workdir> $LSDYNA_VERSION
#
#
# IBM Power
# ---------
# setenv MP_PROCS $LSDYNA_JOB_CPUS
# setenv MP_LABELIO no
# setenv MP_EUILIB us
# setenv MP_EUIDEVICE css0
#
# poe $LSDYNA_VERSION -procs $LSDYNA_JOB_CPUS -hfile $LSDYNA_NODE_FILE
#
#
# SGI IRIX
# --------
# mpirun -np $LSDYNA_JOB_CPUS $LSDYNA_VERSION
#
#
# SUN SPARC
# ---------
# mpirun -np $LSDYNA_JOB_CPUS $LSDYNA_VERSION
#
#
# ============================================================================================
#
#
# ********************************************************************************************
#
# THE REST OF THIS SCRIPT HAS BEEN CONFIGURED FOR SUBMITING LS-DYNA JOBS TO A LINUX SYSTEM USING
# THE PBS QUEUEING SYSTEM.  YOU WILL HAVE TO MODIFY THE FOLLOWING IF YOU ARE USING A DIFFERENT
# QUEUEING STSTEM OR MACHINE TYPE.
#
# ********************************************************************************************
#
#
# Set a default value for NO_PFILE if it's not defined
#
if ( ! $?NO_PFILE ) setenv NO_PFILE FALSE
#
if ( $LSDYNA_MPP !=  "TRUE" && $LSDYNA_HYBRID != "TRUE") then
#
# ============================================================================================
# SMP LS-DYNA submission
# ============================================================================================
#
  $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
else if ($LSDYNA_MPP == "TRUE") then
#
# Create a PFILE which forces the scratch files to a local directory
#
  if ($LSDYNA_QUEUE == "TRUE") then
    if ($NO_PFILE == "TRUE") then
      set pfile_created = "FALSE"
    else
      rm -rf pfile
      echo "directory {" > pfile
      echo "transfer_files" >> pfile
      echo "local /local/$PBS_JOBID" >> pfile
      echo "rmlocal" >> pfile
      echo "global_message_files" >> pfile
      echo "}" >> pfile
      echo "general {" >> pfile
      echo "nofull" >> pfile
      echo "}" >> pfile
    #rm -f names
      /data3/SCRIPTS/modify_names.exe $LSDYNA_JOB_FILE
      set pfile_created = "TRUE"
    endif
  else
    set pfile_created = "FALSE"
  endif
#
# ============================================================================================
# MPP LS-DYNA submission
# ============================================================================================
#
# HP-MPI
#
  if ($LSDYNA_MPI_TYPE == "HP-MPI" || $LSDYNA_MPI_TYPE == "PMPI") then
#
    if ($LSDYNA_MPI_TYPE == "HP-MPI") then
      setenv HPMPI_DIR /opt/hpmpi/bin
    else
      setenv HPMPI_DIR /opt/platform_mpi/bin
    endif
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      if (-e $PBS_NODEFILE) then
        rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
        if (-f $PBS_NODEFILE) then
          foreach roger ( `cat $PBS_NODEFILE` )
            echo "-h $roger -np 1 $LSDYNA_VERSION" $LSDYNA_CL_ARGS >> $LSDYNA_JOB_DIR/appfile
            set LSDYNA_CL_ARGS = ""
          end
        endif
      endif
      $HPMPI_DIR/mpirun -prot -e MPI_WORKDIR=$LSDYNA_JOB_DIR -f  appfile
#      rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
         $HPMPI_DIR/mpirun -prot -np $LSDYNA_JOB_CPUS $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
         $HPMPI_DIR/mpirun -prot -np $LSDYNA_JOB_CPUS -hostfile $NODE_FILE -e LSTC_LICENSE_SERVER=$LSTC_LICENSE_SERVER -e LSTC_LICENSE=$LSTC_LICENSE $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
         $HPMPI_DIR/mpirun -prot -np $LSDYNA_JOB_CPUS -hostlist $NODE_LIST -e LSTC_LICENSE_SERVER=$LSTC_LICENSE_SERVER -e LSTC_LICENSE=$LSTC_LICENSE $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
    endif
#
# INTEL MPI
#
  else if ($LSDYNA_MPI_TYPE == "IMPI") then
#
    setenv INTEL_DIR /opt/intel/impi/5.1.3.223/bin64
    set mpi_dir=$INTEL_DIR
    source $mpi_dir/mpivars.csh
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      $INTEL_DIR/mpirun -env I_MPI_DEBUG=2 -hostfile $PBS_NODEFILE -n $LSDYNA_JOB_CPUS -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_JOB_CPUS -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_JOB_CPUS -machinefile $NODE_FILE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_JOB_CPUS -hosts $NODE_LIST -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
    endif
#
# OPEN MPI
#
  else if ($LSDYNA_MPI_TYPE == "OPENMPI") then
#
    setenv MPI_ROOT /opt/openmpi
    setenv OPENMPI_DIR $MPI_ROOT/bin
#
    if !($?PATH) then
      setenv PATH $MPI_ROOT/bin
    else
      setenv PATH $MPI_ROOT/bin:$PATH
    endif

    if !($?LD_LIBRARY_PATH) then
      setenv LD_LIBRARY_PATH $MPI_ROOT/lib
    else
      setenv LD_LIBRARY_PATH $MPI_ROOT/lib:$LD_LIBRARY_PATH
    endif
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      if (-e $PBS_NODEFILE) then
        rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
        if (-f $PBS_NODEFILE) then
          foreach host ( `cat $PBS_NODEFILE` )
            echo "$host" >> $LSDYNA_JOB_DIR/appfile
          end
        endif
      endif
      $OPENMPI_DIR/mpirun -machinefile appfile -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
         $OPENMPI_DIR/mpirun -n $LSDYNA_JOB_CPUS -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
         $OPENMPI_DIR/mpirun -n $LSDYNA_JOB_CPUS -machinefile $NODE_FILE -x PATH -x LD_LIBRARY_PATH -x LSTC_LICENSE_SERVER -x LSTC_LICENSE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
         $OPENMPI_DIR/mpirun -n $LSDYNA_JOB_CPUS -host $NODE_LIST -x PATH -x LD_LIBRARY_PATH -x LSTC_LICENSE_SERVER -x LSTC_LICENSE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
#
    endif
#
  endif
#
  if ( $pfile_created == "TRUE" ) then
    rm -rf pfile
  endif
#
else if ($LSDYNA_HYBRID == "TRUE") then
#
# ============================================================================================
# HYBRID LS-DYNA submission
# ============================================================================================
#
# HP-MPI / PLATFORM
#
  if ($LSDYNA_MPI_TYPE == "HP-MPI" || $LSDYNA_MPI_TYPE == "PMPI") then
#
    if ($LSDYNA_MPI_TYPE == "HP-MPI") then
      setenv HPMPI_DIR /opt/hpmpi/bin
    else
      setenv HPMPI_DIR /opt/platform_mpi/bin
    endif
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      if (-e $PBS_NODEFILE) then
        rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
        if (-f $PBS_NODEFILE) then
          set last_host = ""
          foreach host ( `sort $PBS_NODEFILE` )
            if ( $host != $last_host) then
              set count = 0
            endif
            @ count = $count + 1
            if ( $count == 1) then
              echo "-h $host -np 1 $LSDYNA_VERSION $LSDYNA_CL_ARGS" >> $LSDYNA_JOB_DIR/appfile
              set LSDYNA_CL_ARGS = ""
            endif
            if ($count == $LSDYNA_HYBRID_SMP_THREADS) then
              set count = 0
            endif
            set last_host = $host
          end
        endif
      endif
      $HPMPI_DIR/mpirun -prot -e MPI_WORKDIR=$LSDYNA_JOB_DIR -f  appfile
#     rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
        $HPMPI_DIR/mpirun -prot -np $LSDYNA_HYBRID_MPP_THREADS $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
        $HPMPI_DIR/mpirun -prot -np $LSDYNA_HYBRID_MPP_THREADS -hostfile $NODE_FILE -e LSTC_LICENSE_SERVER=$LSTC_LICENSE_SERVER -e LSTC_LICENSE=$LSTC_LICENSE $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
        $HPMPI_DIR/mpirun -prot -np $LSDYNA_HYBRID_MPP_THREADS -hostlist $NODE_LIST -e LSTC_LICENSE_SERVER=$LSTC_LICENSE_SERVER -e LSTC_LICENSE=$LSTC_LICENSE $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
    endif
#
# INTEL MPI
#
  else if ($LSDYNA_MPI_TYPE == "INTEL") then
#
    setenv INTEL_DIR /opt/intel/impi/5.1.3.223/bin64
    set mpi_dir=$INTEL_DIR
    source $mpi_dir/mpivars.csh
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      if (-e $PBS_NODEFILE) then
        rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
        if (-f $PBS_NODEFILE) then
          set last_host = ""
          foreach host ( `sort $PBS_NODEFILE` )
            if ( $host != $last_host) then
              set count = 0
            endif
            @ count = $count + 1
            if ( $count == 1) then
              echo "$host" >> $LSDYNA_JOB_DIR/appfile
              set LSDYNA_CL_ARGS = ""
            endif
            if ($count == $LSDYNA_HYBRID_SMP_THREADS) then
              set count = 0
            endif
            set last_host = $host
          end
        endif
      endif
      $INTEL_DIR/mpirun -ibv -n $LSDYNA_HYBRID_MPP_THREADS -machinefile appfile -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_HYBRID_MPP_THREADS -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_HYBRID_MPP_THREADS -machinefile $NODE_FILE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
         $INTEL_DIR/mpirun -n $LSDYNA_HYDIRD_MPP_THREADS -hosts $NODE_LIST -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
    endif
#
# OPEN MPI
#
  else if ($LSDYNA_MPI_TYPE == "OPENMPI") then
#
    setenv MPI_ROOT /opt/openmpi
    setenv OPENMPI_DIR $MPI_ROOT/bin
#
    if !($?PATH) then
      setenv PATH $MPI_ROOT/bin
    else
      setenv PATH $MPI_ROOT/bin:$PATH
    endif

    if !($?LD_LIBRARY_PATH) then
      setenv LD_LIBRARY_PATH $MPI_ROOT/lib
    else
      setenv LD_LIBRARY_PATH $MPI_ROOT/lib:$LD_LIBRARY_PATH
    endif
#
    if ($LSDYNA_QUEUE == "TRUE") then
#
      if (-e $PBS_NODEFILE) then
        rm -rf $LSDYNA_JOB_DIR/appfile >& /dev/null
        if (-f $PBS_NODEFILE) then
          set last_host = ""
          foreach host ( `sort $PBS_NODEFILE` )
            if ( $host != $last_host) then
              set count = 0
            endif
            @ count = $count + 1
            if ( $count == 1) then
              echo "$host" >> $LSDYNA_JOB_DIR/appfile
              set LSDYNA_CL_ARGS = ""
            endif
            if ($count == $LSDYNA_HYBRID_SMP_THREADS) then
              set count = 0
            endif
            set last_host = $host
          end
        endif
      endif
      $OPENMPI_DIR/mpirun -machinefile appfile -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
    else if ($LSDYNA_ONLINE == "TRUE") then
#
      if ($LSDYNA_LOCAL_HOST == "TRUE") then
#
        $OPENMPI_DIR/mpirun -n $LSDYNA_HYBRID_MPP_THREADS -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_FILE == "TRUE") then
#
        $OPENMPI_DIR/mpirun -n $LSDYNA_HYBRID_MPP_THREADS -machinefile $NODE_FILE -x PATH -x LD_LIBRARY_PATH -x LSTC_LICENSE_SERVER -x LSTC_LICENSE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      else if ($LSDYNA_NODE_LIST == "TRUE") then
#
        $OPENMPI_DIR/mpirun -n $LSDYNA_HYBRID_MPP_THREADS -host $NODE_LIST -x PATH -x LD_LIBRARY_PATH -x LSTC_LICENSE_SERVER -x LSTC_LICENSE -wdir $LSDYNA_JOB_DIR $LSDYNA_VERSION $LSDYNA_CL_ARGS
#
      endif
#
    endif
#
  endif
#
endif
#
setenv REPORTER_NO_BATCH_OASYS 1
#
# PRIMER 'ztf' file creation
#
/data4/dyna15/rhe6_64_executables/primer15_64.exe -d=batch -ztf=/u/mid/omannik/restart_tube/small/crush_tube.key > /u/mid/omannik/restart_tube/small/crush_tube.ztf_log 
#
# Set DISPLAY
#
setenv DISPLAY MCCDTCZC7239NJZ:0.0
rm -f dyna.d
rm -f disk8*
